@@ -10,7 +10,7 @@ use Exporter;
 use Storable;
 use Symbol qw(delete_package);
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
@@ -131,6 +131,8 @@ sub install_trace {
         Devel::Examine::Subs->import();
     };
 
+    $@ = 1 if $ENV{EVAL_TEST}; # for test coverage
+
     if ($@){
         die "can't load Devel::Examine::Subs!: $@";
     }
@@ -168,6 +170,8 @@ sub remove_trace {
         Devel::Examine::Subs->import();
     };
 
+    $@ = 1 if $ENV{EVAL_TEST}; # for test coverage
+
     if ($@){
         die "can't load Devel::Examine::Subs!: $@";
     }
@@ -201,8 +205,7 @@ sub _store {
 
     my $data = shift;
 
-    my $pid = $ENV{DTS_PID} || shift;
-    my $store = "DTS_" . join('_', ($pid x 3)) . ".dat";
+    my $store = "DTS_" . join('_', ($$ x 3)) . ".dat";
 
     $ENV{DTS_STORE} = $store;
 
@@ -233,6 +236,9 @@ __END__
 Devel::Trace::Subs - Generate, track, store and print code flow and stack
 traces.
 
+=for html
+<a href="http://travis-ci.org/stevieb9/devel-trace-subs"><img src="https://secure.travis-ci.org/stevieb9/devel-trace-subs.png"/>
+<a href='https://coveralls.io/github/stevieb9/devel-trace-subs?branch=master'><img src='https://coveralls.io/repos/stevieb9/devel-trace-subs/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
 
 =head1 SYNOPSIS
 
@@ -401,8 +407,6 @@ L<https://github.com/stevieb9/devel-trace-subs>
 
 =head1 BUILD REPORTS
 
-Travis-CI: L<https://travis-ci.org/stevieb9/devel-trace-subs>
-
 CPAN Testers: L<http://matrix.cpantesters.org/?dist=Devel-Trace-Subs>
 
 =head1 SUPPORT
@@ -429,7 +433,7 @@ L<http://search.cpan.org/dist/Devel-Trace-Subs/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015 Steve Bertrand.
+Copyright 2016 Steve Bertrand.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
